<?php

$LANG = array(

'L_MENU'													=> 'Menu',
'L_UNKNOWN_ERROR'											=> 'Errore sconosciuto',
'L_CONFIRM_DELETE'											=> 'Confermare l\'eliminazione ?',
'L_SAVE_FILE'												=> 'Salvare il file',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'File salvato con successo',
'L_SAVE_FILE_ERROR'											=> 'Salvataggio del file per errore',
'L_REPLY'													=> 'Rispondere',
'L_REPLY_TO'												=> 'Rispondere',
'L_CANCEL'													=> 'Annullare',
'L_DELETE'													=> 'Cancella',
'L_DELETE_FILE' 				    						=> 'Cancella il file',
'L_DELETE_FOLDER'				   							=> 'Eliminare la cartella',
'L_THUMBNAIL'												=> 'Miniatura (facoltativo)',
'L_THUMBNAIL_SELECTION'										=> 'Seleziona immagine',
'L_THUMBNAIL_TITLE'											=> 'Immagine Titolo (facoltativo)',
'L_THUMBNAIL_ALT'											=> 'Testo alternativo dell\'immagine (facoltativo)',
'L_SAVE_SUCCESSFUL'											=> 'Dati salvati con successo',
'L_SAVE_ERR'												=> 'Errore durante il salvataggio dei dati',
'L_NO_ENTRY'												=> 'Accesso non consentito',
'L_ERR_USER_EMPTY'											=> 'Inserisci un nome utente',
'L_ERR_PASSWORD_EMPTY'										=> 'Inserisci una password',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'Conferma della password errata o non esistente',
'L_ERR_INVALID_EMAIL'										=> 'Indirizzo email non valido',
'L_ERR_INVALID_SITE'										=> 'Indirizzo del sito non valido',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'ID dell\'articolo non valido',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'nuova-categoria',
'L_DEFAULT_NEW_STATIC_URL'									=> 'nuova-pagina',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'nuovo-articolo',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Articolo creato con successo',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Articolo aggiornato con successo',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Articolo cancellato con successo',
'L_ARTICLE_SAVE_ERR'										=> 'Errore durante il salvataggio dell\'articolo',
'L_ARTICLE_DELETE_ERR'										=> 'Errore durante la cancellazione dell\'articolo',
'L_ERR_UNKNOWN_COMMENT'										=> 'Il commento richiesto non esiste oppure è stato cancellato',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Commento modificato con successo',
'L_COMMENT_UPDATE_ERR'										=> 'Errore durante l\'aggiornamento del commento',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Commento cancellato con successo',
'L_COMMENT_DELETE_ERR'										=> 'Errore durante la cancellazione del commento',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Pubblicazione del commento avvenuta con successo',
'L_COMMENT_VALIDATE_ERR'									=> 'Errore durante la pubblicazione del commento',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Il commento è stato moderato con successo',
'L_COMMENT_MODERATE_ERR'									=> 'Errore durante la moderazione del commento',
'L_COMMENT_WRITTEN_BY'										=> 'Pubblicato da',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Impossibile creare la cartella media per l\'utente in uso',
'L_PLXMEDIAS_ROOT'											=> 'radice',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Impossibile creare la cartella',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'Cartella creata con successo',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'Questa cartella esiste già',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Errore durante la cancellazione della cartella',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'Cartella cancellata con successo',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'Il tipo di file non è permesso',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'La dimensione di un file è maggiore di',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Errore durante l\'invio un file',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'File inviato con successo',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Errore durante il caricamento di file',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'I file inviati con successo',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'Rimosso con successo i file',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Errore durante l\'eliminazione di un file',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'File eliminato con successo',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Errore durante l\'eliminazione del file',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'Errore durante lo spostamento dei file',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'Errore durante lo spostamento del file',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'I file sono stati spostati con successo',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'Il file è stato spostato con successo',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Sposta',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Errore durante la creazione della miniatura',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Errore nella creazione delle miniature',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Miniature creato con successo',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Miniature creato con successo',
'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'Nuovo articolo',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Data di pubblicazione non valida',
'L_ERR_UNKNOWN_ARTICLE'										=> 'L\'articolo richiesto non esiste o è stato cancellato !',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'Non disponi dei diritti per accedere a questo articolo !',
'L_BACK_TO_ARTICLES'										=> 'Ritorna alla lista degli articoli',
'L_ARTICLE_EDITING'											=> 'Modifica articolo',
'L_ARTICLE_TITLE'											=> 'Titolo',
'L_ARTICLE_LIST_AUTHORS'									=> 'Autore',
'L_HEADLINE_FIELD'											=> 'Premessa (facoltativo)',
'L_CONTENT_FIELD'											=> 'Contenuto',
'L_LINK_FIELD'												=> 'Link all\'articolo',
'L_LINK_ACCESS'												=> 'Vai all\'articolo',
'L_LINK_VIEW'												=> 'vedere',
'L_ARTICLE_STATUS'											=> 'Stato',
'L_DRAFT'													=> 'Bozza',
'L_PUBLISHED'												=> 'Pubblicato',
'L_AWAITING'												=> 'In attesa di convalida',
'L_ARTICLE_DATE'											=> 'Data di pubblicazione',
'L_NOW'														=> 'adesso',
'L_ARTICLE_CATEGORIES'										=> 'Categoria',
'L_CATEGORY_HOME_PAGE'										=> 'Homepage',
'L_NEW_CATEGORY'											=> 'Nuova categoria',
'L_ARTICLE_TAGS_FIELD'										=> 'Tag',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Separa i tag con una virgola',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Lista dei tag',
'L_NO_TAG'													=> 'Nessuna tag presente',
'L_ALLOW_COMMENTS'											=> 'Autorizza i commenti',
'L_ARTICLE_URL_FIELD'										=> 'Url',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'Il campo URL si riempie automaticamente durante la creazione',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Modello',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Gestisci i commenti',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Gestisci i commenti dell\'articolo',
'L_ARTICLE_NEW_COMMENT'										=> 'Scrivi un commento',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Scrivi un commento sull\'articolo',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Vuoi cancellare questo articolo ?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Anteprima',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Salva la bozza',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Pubblica',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Sottoporre per l\'approvazione',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Disabilita',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Registra',
'L_CATEGORY_ADD_BUTTON'										=> 'Aggiungi',
'L_ARTICLE_META_DESCRIPTION'								=> 'Contenuto del meta tag "description" (facoltativo)',
'L_ARTICLE_META_KEYWORDS'									=> 'Contenuto del meta tag "keywords" (facoltativo)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Titolo contenuto tag (opzionale)',
'L_ARTICLE_CHAPO_HIDE'										=> 'nascondere',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'mostrare',
'L_ARTICLE'													=> 'articolo',
'L_ARTICLE_ID'												=> 'ID',
'L_AUTH_PAGE_TITLE'											=> 'Pagina di autenticazione',
'L_LOGOUT_SUCCESSFUL'										=> 'Disconnessione avvenuta con successo',
'L_LOGIN_PAGE'												=> 'Pannello di amministrazione',
'L_AUTH_LOGIN_FIELD'										=> 'Nome utente',
'L_AUTH_PASSWORD_FIELD'										=> 'Password',
'L_SUBMIT_BUTTON'											=> 'Collegati',
'L_ERR_WRONG_PASSWORD'										=> 'Nome utente e/o password non corretti',
'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
'L_CAT_TITLE'												=> 'Gestione categorie',
'L_CAT_LIST_ID'												=> 'ID',
'L_CAT_LIST_ACTIVE'											=> 'Attiva',
'L_CAT_LIST_NAME'											=> 'Nome categoria',
'L_CAT_LIST_URL'											=> 'Url',
'L_CAT_LIST_SORT'											=> 'Ordinamento',
'L_CAT_LIST_BYPAGE'											=> 'N. art/pagina',
'L_CAT_LIST_ORDER'											=> 'Ordine',
'L_CAT_LIST_MENU'											=> 'Menu',
'L_CATEGORY'												=> 'Categoria',
'L_DISPLAY'													=> 'Visualizza',
'L_HIDE'													=> 'Nascondi',
'L_OPTIONS'													=> 'Opzioni',
'L_FOR_SELECTION'											=> 'Se selezionati...',
'L_CAT_APPLY_BUTTON'										=> 'Modifica la lista delle categorie',
'L_CAT_UNKNOWN'												=> 'categoria sconosciuta',
'L_EDITCAT_PAGE_TITLE'										=> 'Gestisci le opzioni delle categorie',
'L_EDITCAT_DESCRIPTION'										=> 'Descrizione',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Mostra articoli in questa categoria nella home page',
'L_EDITCAT_TEMPLATE'										=> 'Modello',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Ritorna alla lista delle categorie',
'L_EDITCAT_UPDATE'											=> 'Aggiorna questa categoria',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Titolo contenuto tag (opzionale)',
'L_EDITCAT_META_DESCRIPTION'								=> 'Contenuto del meta tag "description" per questa categoria (facoltativo)',
'L_EDITCAT_META_KEYWORDS'									=> 'Contenuto del meta tag "keywords" per questa categoria (facoltativo)',
'L_COMMENT_ORPHAN'											=> 'nessun articolo',
'L_COMMENT_ORPHAN_STATUS'									=> 'non visibile (consiglio: cancella questo commento)',
'L_COMMENT_ARTICLE_LINKED'									=> 'Articolo',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Articolo collegato a questo commento',
'L_COMMENT_OFFLINE'											=> 'disabilitato',
'L_COMMENT_ONLINE'											=> 'attivo',
'L_COMMENT_ONLINE_TITLE'									=> 'Visualizza questo commento sul sito',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Ritorna alla lista dei commenti di questo articolo',
'L_BACK_TO_COMMENTS'										=> 'Ritorna alla lista dei commenti',
'L_COMMENT_EDITING'											=> 'Modifica un commento',
'L_COMMENT_AUTHOR_FIELD'									=> 'Autore',
'L_COMMENT_TYPE_FIELD'										=> 'Tipo di commento',
'L_COMMENT_DATE_FIELD'										=> 'Data e ora di pubblicazione',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'Sito',
'L_COMMENT_EMAIL_FIELD'										=> 'Email',
'L_COMMENT_STATUS_FIELD'									=> 'Stato',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Articolo correlato;',
'L_COMMENT_ARTICLE_FIELD'									=> 'Commento',
'L_COMMENT_DELETE_CONFIRM'									=> 'Vuoi cancellare questo commento ?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Pubblica',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Disabilita',
'L_COMMENT_ANSWER_BUTTON'									=> 'Rispondi a questo commento',
'L_COMMENT_UPDATE_BUTTON'									=> 'Aggiorna',
'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'Il commento non esiste o non è più disponibile !',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'Il commento è stato disabilitato, non è possibile rispondere !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'L\'articolo richiesto non esiste o non è più possibile scrivere un commento !',
'L_ERR_CREATING_COMMENT'									=> 'Errore durante la creazione del commento',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'Il commento è stato creato con successo',
'L_CREATE_NEW_COMMENT'										=> 'Scrivi un commento',
'L_COMMENT_SAVE_BUTTON'										=> 'Salva',
'L_ARTICLE_COMMENTS_LIST'									=> 'Commenti dell\'articolo (dal più recente al più vecchio)',
'L_COMMENT_ANSWER_TITLE'									=> 'Rispondi a questo commento',
'L_COMMENT_ANSWER'											=> 'Rispondi',
'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Scrivi un nuovo commento per questo articolo',
'L_COMMENT_NEW_COMMENT'										=> 'Scrivi un nuovo commento',
'L_COMMENTS_ARTICLE_SCOPE'									=> 'Articolo',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'sito intero',
'L_COMMENTS_OFFLINE_LIST'									=> 'Lista dei commenti in attesa di pubblicazione ',
'L_COMMENTS_LIST_DATE'										=> 'Data',
'L_COMMENTS_LIST_AUTHOR'									=> 'Autore',
'L_COMMENTS_LIST_MESSAGE'									=> 'Messaggio',
'L_COMMENTS_LIST_ACTION'									=> 'Azione',
'L_COMMENT_EDIT'											=> 'Modifica',
'L_COMMENT_EDIT_TITLE'										=> 'Modifica questo commento',
'L_COMMENT_DELETE'											=> 'Cancella',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'Rss dei commenti disabilitati',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Commenti disabilitati',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'Rss dei commenti abilitati',
'L_COMMENT_ONLINE_FEEDS'									=> 'Commenti abilititati',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Feed privati',
'L_COMMENTS_ONLINE_LIST'									=> 'Lista delle recensioni pubblicate',
'L_COMMENTS_ALL_LIST'										=> 'Elenca commenti',
'L_COMMENT_SET_ONLINE'										=> 'Carica',
'L_COMMENT_SET_OFFLINE'										=> 'Non in linea',
'L_ARTICLES_FILTER_BUTTON'									=> 'Filtra',
'L_CATEGORIES_TABLE'										=> 'Categorie',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Categorie specifiche',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'Tutti gli articoli',
'L_ARTICLES_LIST'											=> 'Lista degli articoli',
'L_ARTICLE_LIST_DATE'										=> 'Data',
'L_ARTICLE_LIST_TITLE'										=> 'Titolo',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Categoria',
'L_ARTICLE_LIST_NBCOMS'										=> 'No commenti',
'L_ARTICLE_LIST_AUTHOR'										=> 'Autore',
'L_ARTICLE_LIST_ACTION'										=> 'Azione',
'L_CATEGORY_HOME'											=> 'Homepage',
'L_CATEGORY_DRAFT'											=> 'Bozza',
'L_ARTICLE_VIEW'											=> 'Visualizza',
'L_ARTICLE_VIEW_TITLE'										=> 'Visualizza questo articolo sul sito',
'L_ARTICLE_EDIT'											=> 'Modifica',
'L_ARTICLE_EDIT_TITLE'										=> 'Modifica questo articolo',
'L_NEW_COMMENTS_TITLE'										=> 'Commenti in attesa di pubblicazione',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Commenti pubblicati',
'L_NO_ARTICLE'												=> 'Nessun articolo',
'L_ARTICLES_SEARCH_BUTTON'									=> 'Cerca',
'L_ARTICLES_ALL_CATEGORIES'									=> 'Tutte le categorie ...',
'L_ALL'														=> 'Tutte le',
'L_ALL_PUBLISHED'											=> 'Edizione',
'L_ALL_DRAFTS'												=> 'Bozze',
'L_ALL_AWAITING_MODERATION'									=> 'In attesa di convalida',
'L_MEDIAS_DELETE_FOLDER'									=> 'Cancella questa cartella',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Vuoi cancellare la cartella %s e il suo contenuto ?',
'L_MEDIAS_NO_FILE'											=> 'Nessun file',
'L_MEDIAS_FILENAME'											=> 'Nome del file',
'L_MEDIAS_ADD_FILE'											=> 'Aggiungi file',
'L_MEDIAS_BACK'												=> 'Indietro',
'L_MEDIAS_TITLE'											=> 'Gestione dei media',
'L_MEDIAS_IMAGES'											=> 'Immagini',
'L_MEDIAS_DOCUMENTS'										=> 'Documenti',
'L_MEDIAS_CREATE_FOLDER'									=> 'Crea una cartella',
'L_MEDIAS_SUBMIT_FILE'										=> 'Invia',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Dimensione max dei file',
'L_MEDIAS_DIRECTORY'										=> 'Posizione',
'L_MEDIAS_FOLDER'											=> 'File',
'L_MEDIAS_NEW_FOLDER'										=> 'Nuova Cartella',
'L_MEDIAS_FILESIZE'											=> 'Dimensioni',
'L_MEDIAS_DATE'												=> 'Data',
'L_MEDIAS_DIMENSIONS'										=> 'Dimensioni',
'L_MEDIAS_RESIZE'											=> 'Ridimensionare Immagini',
'L_MEDIAS_RESIZE_NO'										=> 'Dimensioni originali',
'L_MEDIAS_THUMBS'											=> 'Crea anteprima',
'L_MEDIAS_THUMBS_NONE'										=> 'Nessuna anteprima',
'L_MEDIAS_MODIFY'											=> 'Modifica',
'L_MEDIAS_THUMB'											=> 'Thumbnail',
'L_MEDIAS_EXTENSION'										=> 'Estensione',
'L_MEDIAS_ADD'												=> 'Aggiungi',
'L_MEDIAS_ALIGNMENT'										=> 'Allineamento',
'L_MEDIAS_ALIGN_NONE'										=> 'No',
'L_MEDIAS_ALIGN_LEFT'										=> 'Sinistra',
'L_MEDIAS_ALIGN_CENTER'										=> 'Centro',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Diritto',
'L_MEDIAS_RECREATE_THUMB'									=> 'Ricrea thumbnail',
'L_SORT_ASCENDING_DATE'										=> 'data ascendente',
'L_SORT_DESCENDING_DATE'									=> 'data discendente',
'L_SORT_ALPHABETICAL'										=> 'alfabetico',
'L_OK'														=> 'Ok',
'L_YES'														=> 'Si',
'L_NO'														=> 'No',
'L_NONE1'													=> 'nessuno',
'L_NONE2'													=> 'nessuna',
'L_CONFIG_VIEW_FIELD'										=> 'Opzioni di visualizzazione',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Scelta del tema',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Modifica i file del tema',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Modifica i file del tema',
'L_CONFIG_VIEW_SORT'										=> 'Ordinamento degli articoli',
'L_CONFIG_VIEW_BYPAGE'										=> 'Numero di articoli visualizzati per pagina',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Numero di articoli visualizzati per pagina nell\'archivio',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Numero di articoli visualizzati per pagina nel pannello di amministrazione',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Ordinamento dei commenti',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Numero di commenti visualizzati per nel pannello di amministrazione',
'L_CONFIG_VIEW_IMAGES'										=> 'Immagine Dimensioni (larghezza x altezza)',
'L_CONFIG_VIEW_THUMBS'										=> 'Dimensione delle miniature (larghezza x altezza)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'Usa una pagina statica come homepage',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Attenzione, questa pagina non è attiva',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Scarica altri temi su <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'Numero di articoli/commenti visualizzati',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Visualizzare solo la premessa degli articoli',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Se la premessa è vuota, visualizza il contenuto',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Testo da aggiungere come firma in basso ad ogni flusso Rss degli articoli',
'L_CONFIG_VIEW_UPDATE'										=> 'Modifica le opzioni di visualizzazione',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Visualizzare le categorie senza l\'articolo',
'L_CONFIG_HOMETEMPLATE'										=> 'Modello della homepage',
'L_CONFIG_ADVANCED_DESC'									=> 'Configurazione avanzata',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Abilita la riscrittura degli url',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Attenzione un file .htaccess è già presente alla radice di PluXml. Abilitando la riscrittura degli url questo file sarà modificato',
'L_CONFIG_ADVANCED_GZIP'									=> 'Abilita la compressione GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Consente la compressione delle pagine per ridurre la banda utilizzata, ciò potrebbe richiedere un maggiore utilizzo del processore',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Abilita il capcha anti-spam',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Chiave di amministrazione (URL privati)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Svuota questo campo per rigenerare la chiave',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Usare delle cartelle medias diverse per ogni user',
'L_HELP_SLASH_END'											=> 'Non dimenticare la slash alla fine',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Posizione media (cartella)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Posizionamento degli articoli(cartella)',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Posizionamento dei commenti (cartella)',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Posizionamento delle pagine statiche (cartella)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Posizionamento dei argomenti (cartella)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Posizionamento dei plugin (cartella)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Posizionamento dei file di configurazione (cartella)',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Modifica la configurazione avanzata',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Ubicazione e nome del file CSS personalizzato dell\'area amministrazione (optional)',
'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Configurazione base',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Titolo del sito',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Sottotitolo/descrizione del sito',
'L_CONFIG_BASE_URL_HELP'									=> 'Non dimenticare la slash alla fine',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Lingua predefinita del sito',
'L_CONFIG_BASE_TIMEZONE'									=> 'Fuso orario',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Autorizza i commenti',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Modera i commenti durante la creazione',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'Modera gli articoli per i profili redattore ed editore',
'L_CONFIG_BASE_UPDATE'										=> 'Modifica la configurazione base',
'L_CONFIG_META_DESCRIPTION'									=> 'Contenuto della meta tag "description" del sito (facoltativo)',
'L_CONFIG_META_KEYWORDS'									=> 'Contenuto della meta tag "keywords" del sito (facoltativo)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'Questo tema non esiste !',
'L_CONFIG_EDITTPL_TITLE'									=> 'Modifica il tema',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Scelta del file da modificare',
'L_CONFIG_EDITTPL_LOAD'										=> 'Carica',
'L_CONFIG_INFOS_TITLE'										=> 'Informazioni relative a PluXml',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Informazioni di dettaglio sul funzionamento di PluXml, possono essere utili per richiedere assistenza.',
'L_CONFIG_INFOS_NB_CATS'									=> 'Numero di categorie',
'L_CONFIG_INFOS_NB_STATICS'									=> 'Numero di pagine statiche :',
'L_CONFIG_INFOS_WRITER'										=> 'Nome dell\'utente collegato :',
'L_PLUXML_CHECK_VERSION'									=> 'Verifica della versione di PluXml sul sito ufficiale PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Impossibile verificare gli aggiornamenti perchè \'allow_url_fopen\' è disattivato su questo sistema',
'L_PLUXML_UPDATE_ERR'										=> 'Verifica degli aggiornamenti non riuscita',
'L_PLUXML_UPTODATE'											=> 'State utilizzando l\'ultima versione di PluXml',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'Una nuova versione di PluXml è disponibile su',
'L_CONFIG_USERS_TITLE'										=> 'Gestione utenti',
'L_CONFIG_USER'												=> 'Utente',
'L_CONFIG_USERS_ID'											=> 'ID utente',
'L_CONFIG_USERS_ACTIVE'										=> 'Attivo',
'L_CONFIG_USERS_ACTION'										=> 'Azione',
'L_CONFIG_USERS_NEW'										=> 'Nuovo utente',
'L_CONFIG_USERS_UPDATE'										=> 'Modifica la lista degli utenti',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'Login ID già usato',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Username già in uso',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Categoria nome già usato',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Come già usato',
'L_BACK_TO_PLUGINS'											=> 'Ritornare alla pagina dei plugin',
'L_NO_PLUGIN'												=> 'Nessun plugin',
'L_PLUGIN_NO_CONFIG'										=> 'Plugin non configurato',
'L_PLUGINS_CSS'												=> 'Css',
'L_PLUGINS_CSS_TITLE'										=> 'Modificare il codice css del plugin',
'L_CONTENT_FIELD_FRONTEND'									=> 'Sito web contenuto del file Css',
'L_CONTENT_FIELD_BACKEND'									=> 'Amministratore contenuti css',
'L_PLUGINS_TITLE'											=> 'Gestione plugin',
'L_PLUGINS_VERSION'											=> 'Versione',
'L_PLUGINS_AUTHOR'											=> 'Autore',
'L_PLUGINS_ACTIVATE'										=> 'Abilita',
'L_PLUGINS_DEACTIVATE'										=> 'Disabilita',
'L_PLUGINS_DELETE'											=> 'Cancella',
'L_PLUGINS_DELETE_ERROR'									=> 'Errore durante la cancellazione',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Cancellazione avvenuta con successo',
'L_PLUGINS_CONFIG'											=> 'Configurazione',
'L_PLUGINS_CONFIG_TITLE'									=> 'Configurazione del plugin',
'L_PLUGINS_REQUIREMENTS'									=> 'Prerequisiti',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dei plugin presenti e attivi per attivare questo plugin',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nessuno',
'L_PLUGINS_ALPHA_SORT'										=> 'Ordine alfabetico plugins',
'L_PLUGINS_LOADING_SORT'									=> 'Caricamento in corso per',
'L_PLUGINS_ACTION'											=> 'Azione',
'L_PLUGINS_APPLY_BUTTON'									=> 'Modificare l\'elenco dei plugin',
'L_PLUGINS_ACTIVE_LIST'										=> 'Plugins attivi',
'L_PLUGINS_INACTIVE_LIST'									=> 'Plugins inattivi',
'L_PROFIL_EDIT_TITLE'										=> 'Gestione profilo',
'L_PROFIL'													=> 'Profilo',
'L_PROFIL_LOGIN'											=> 'Nome utente',
'L_PROFIL_USER'												=> 'Nome utente',
'L_PROFIL_MAIL'												=> 'Indirizzo email',
'L_PROFIL_ADMIN_LANG'										=> 'Lingua usata nel pannello di amministrazione',
'L_PROFIL_INFOS'											=> 'Informazioni',
'L_PROFIL_UPDATE'											=> 'Modifica il profilo',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Cambia la password',
'L_PROFIL_PASSWORD'											=> 'Password',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Conferma la password',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Cambia la password',
'L_STATIC_BACK_TO_PAGE'										=> 'Ritorna alla lista delle pagine statiche',
'L_STATIC_UNKNOWN_PAGE'										=> 'Questa pagina statica non esiste oppure è stato cancellata !',
'L_STATIC_TITLE'											=> 'Modifica il codice della pagina statica',
'L_STATIC_VIEW_PAGE'										=> 'Visualizza la pagina',
'L_STATIC_ON_SITE'											=> 'sul sito',
'L_STATIC_UPDATE'											=> 'Salva questa pagina statica',
'L_STATIC_TITLE_HTMLTAG'									=> 'Titolo contenuto tag (opzionale)',
'L_STATIC_META_DESCRIPTION'									=> 'Contenuto della meta tag "description" per questa pagina statica (facoltativo)',
'L_STATIC_META_KEYWORDS'									=> 'Contenuto della meta tag "keywords" per questa pagina statica (facoltativo)',
'L_STATICS_PAGE_TITLE'										=> 'Gestione pagine statiche',
'L_STATICS_ID'												=> 'ID',
'L_STATICS_GROUP'											=> 'Gruppo',
'L_STATICS_TITLE'											=> 'Titolo',
'L_STATICS_URL'												=> 'Url',
'L_STATICS_ACTIVE'											=> 'Attiva',
'L_STATICS_ORDER'											=> 'Ordine',
'L_STATICS_MENU'											=> 'Menu',
'L_STATICS_ACTION'											=> 'Azione',
'L_STATICS_TEMPLATE_FIELD'									=> 'Modello',
'L_STATICS_PAGE_HOME'										=> 'Imposta come pagine iniziale',
'L_STATICS_HOME_PAGE'										=> 'Homepage',
'L_PAGE'													=> 'Pagina',
'L_VIEW'													=> 'Visualizza',
'L_STATICS_SRC_TITLE'										=> 'Modifica il codice di questa pagina',
'L_STATICS_SRC'												=> 'Modifica',
'L_STATICS_NEW_PAGE'											=> 'Nuova pagina',
'L_STATICS_UPDATE'											=> 'Modifica la lista delle pagine statiche',
'L_PROFIL_ADMIN'											=> 'Amministratore',
'L_PROFIL_MANAGER'											=> 'Manager',
'L_PROFIL_MODERATOR'										=> 'Moderatore',
'L_PROFIL_EDITOR'											=> 'Editore',
'L_PROFIL_WRITER'											=> 'Redattore',
'L_ADMIN'													=> '- Amministrazione',
'L_LOGIN'													=> 'Connesso come',
'L_ADMIN_LOGOUT'											=> 'Disconnettiti',
'L_ADMIN_LOGOUT_TITLE'										=> 'Esci dal pannello di amministrazione',
'L_BACK_TO_SITE'											=> 'Home',
'L_BACK_TO_SITE_TITLE'										=> 'Ritorna al sito',
'L_BACK_TO_BLOG'											=> 'Blog',
'L_BACK_TO_BLOG_TITLE'										=> 'Ritorna al blog',
'L_MENU_ARTICLES'											=> 'Articoli',
'L_MENU_ARTICLES_TITLE'										=> 'Gestisci gli articoli',
'L_MENU_NEW_ARTICLES'										=> 'Nuovo articolo',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'Nuovo articolo',
'L_MENU_STATICS_TITLE'										=> 'Gestisci le pagine statiche',
'L_MENU_STATICS'											=> 'Pagine statiche',
'L_MENU_COMMENTS_TITLE'										=> 'Gestisci i commenti',
'L_MENU_COMMENTS'											=> 'Commenti',
'L_MENU_MEDIAS_TITLE'										=> 'Gestisci i media',
'L_MENU_MEDIAS'												=> 'Media',
'L_MENU_CATEGORIES_TITLE'									=> 'Gestisci le categorie',
'L_MENU_CATEGORIES'											=> 'Categorie',
'L_MENU_CONFIG_TITLE'										=> 'Configura PluXml',
'L_MENU_CONFIG'												=> 'Parametri',
'L_MENU_PROFIL_TITLE'										=> 'Gestisci il profilo',
'L_MENU_PROFIL'												=> 'Profilo',
'L_WARNING_INSTALLATION_FILE'								=> 'Il file install.php è presente nella radice di PluXml.<br />Per motivi di sicurezza, è fortemente consigliata la cancellazione.',
'L_USER_UNKNOWN'											=> 'Utente sconosciuto',
'L_USER_LANG'												=> 'Lingua usata nel pannello di amministrazione',
'L_USER_MAIL'												=> 'Indirizzo email',
'L_USER_INFOS'												=> 'Informazioni',
'L_USER_UPDATE'												=> 'Aggiorna utente',
'L_USER_PAGE_TITLE'											=> 'Modifica le opzioni dell\'utente',
'L_USER_BACK_TO_PAGE'										=> 'Ritorna alla lista degli utenti',
'L_MENU_CONFIG_BASE_TITLE'									=> 'Configurazione di base',
'L_MENU_CONFIG_BASE'										=> 'Configurazione base',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'Gestione opzioni di visualizzazione',
'L_MENU_CONFIG_VIEW'										=> 'Opzioni di visualizzazione',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Gestisci gli utenti',
'L_MENU_CONFIG_USERS'										=> 'Utenti',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Gestione della configurazione avanzata',
'L_MENU_CONFIG_ADVANCED'									=> 'Configurazione avanzata',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Ottieni informazioni sulla versione di PluXml in uso',
'L_MENU_CONFIG_INFOS'										=> 'Informazioni',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Gestisci i plugin',
'L_MENU_CONFIG_PLUGINS'										=> 'Plugin',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Url già in uso. Si prega di modificare il valore del campo \'Url\'',
'L_THEMES'													=> 'Temi',
'L_THEMES_TITLE'											=> 'Gestire i temi',
'L_HELP'													=> 'Aiuto',
'L_HELP_TITLE'												=> 'Vedere l\'aiuto',
'L_BACK_TO_THEMES'											=> 'Torna alla pagina dei temi',
'L_ERR_INVALID_DATE_CREATION'								=> 'Data di creazione non valida',
'L_ERR_INVALID_DATE_UPDATE'									=> 'Data non valida aggiornato',
);
?>
